==> wine-1.3.15.tar.bz2: wine-1.3.15/programs/winemine/resource.h <==
/*
 * WineMine (resource.h)
 *
 * Copyright 2000 Joshua Thielen
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#include <windef.h>
#include <winuser.h>

#define ID_TIMER        1000

/* menu defines */
#define IDM_NEW        1001
#define IDM_EXIT       1002
#define IDM_TIMES      1003
#define IDM_ABOUT      1004
#define IDM_BEGINNER   1005
#define IDM_ADVANCED   1006
#define IDM_EXPERT     1007
#define IDM_CUSTOM     1008
#define IDM_MARKQ      1009

#define IDC_TIME1      1011
#define IDC_TIME2      1012
#define IDC_TIME3      1013
#define IDC_NAME1      1014
#define IDC_NAME2      1015
#define IDC_NAME3      1016

#define IDC_EDITNAME   1021

#define IDC_EDITCOLS   1031
#define IDC_EDITROWS   1032
#define IDC_EDITMINES  1033

#define IDS_APPNAME    1101
#define IDS_NOBODY     1102
#define IDS_ABOUT      1103

#define IDA_WINEMINE   1201

==> wine1.6_1.6.2.orig.tar.bz2: wine-1.6.2/programs/winemine/resource.h <==
/*
 * WineMine (resource.h)
 *
 * Copyright 2000 Joshua Thielen
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#include <windef.h>
#include <winuser.h>

#define ID_TIMER        1000

/* menu defines */
#define IDM_NEW        1001
#define IDM_EXIT       1002
#define IDM_TIMES      1003
#define IDM_ABOUT      1004
#define IDM_BEGINNER   1005
#define IDM_ADVANCED   1006
#define IDM_EXPERT     1007
#define IDM_CUSTOM     1008
#define IDM_MARKQ      1009

#define IDC_TIME1      1011
#define IDC_TIME2      1012
#define IDC_TIME3      1013
#define IDC_NAME1      1014
#define IDC_NAME2      1015
#define IDC_NAME3      1016

#define IDC_EDITNAME   1021

#define IDC_EDITCOLS   1031
#define IDC_EDITROWS   1032
#define IDC_EDITMINES  1033

#define IDS_APPNAME    1101
#define IDS_NOBODY     1102
#define IDS_ABOUT      1103

#define IDA_WINEMINE   1201

#define IDM_WINEMINE   1

#define IDI_WINEMINE   1
#define IDI_FACES      2
#define IDI_LEDS       3
#define IDI_MINES      4

#define DLG_TIMES      1
#define DLG_CONGRATS   2
#define DLG_CUSTOM     3
